<?php

namespace Tag\Tag\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Tag\Tag\Models\Tag;

class TagPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the tag.
     *
     * @param User $user
     * @param Tag $tag
     *
     * @return bool
     */
    public function view(User $user, Tag $tag)
    {
        if ($user->canDo('tag.tag.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $tag->user_id;
    }

    /**
     * Determine if the given user can create a tag.
     *
     * @param User $user
     * @param Tag $tag
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('tag.tag.create');
    }

    /**
     * Determine if the given user can update the given tag.
     *
     * @param User $user
     * @param Tag $tag
     *
     * @return bool
     */
    public function update(User $user, Tag $tag)
    {
        if ($user->canDo('tag.tag.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $tag->user_id;
    }

    /**
     * Determine if the given user can delete the given tag.
     *
     * @param User $user
     * @param Tag $tag
     *
     * @return bool
     */
    public function delete(User $user, Tag $tag)
    {
        if ($user->canDo('tag.tag.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $tag->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
